Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(481)

Unified Diff: ui/webui/resources/js/cr/ui/focus_row.js

Issue 2749513004: MD Settings: adjust iron-list focus row behaviors. (Closed)
Patch Set: format and add left-out file Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/webui/resources/js/cr/ui/focus_row.js
diff --git a/ui/webui/resources/js/cr/ui/focus_row.js b/ui/webui/resources/js/cr/ui/focus_row.js
index 652b0353f61a2ab23e4fb8dda774747ac55322f6..bfe13e23b67512b650d6dad924213c4bea6a40c5 100644
--- a/ui/webui/resources/js/cr/ui/focus_row.js
+++ b/ui/webui/resources/js/cr/ui/focus_row.js
@@ -105,13 +105,18 @@ cr.define('cr.ui', function() {
* to indicate they're equivalent.
*
* @param {string} type The type of element to track focus of.
* @param {string} query The selector of the element from this row's root.
Dan Beam 2017/03/18 00:09:57 selectorOrElement
scottchen 2017/03/18 01:05:47 Done.
+ * this row's root, or the element itself.
* @return {boolean} Whether a new item was added.
*/
- addItem: function(type, query) {
+ addItem: function(type, selector) {
assert(type);
- var element = this.root.querySelector(query);
+ var element;
+ if (selector instanceof HTMLElement)
Dan Beam 2017/03/18 00:09:57 typeof selector == 'string' is better (works acros
scottchen 2017/03/18 01:05:47 Acknowledged.
+ element = selector;
+ else
+ element = this.root.querySelector(/** @type {string} */ (selector));
Dan Beam 2017/03/18 00:09:57 if (typeof selectorOrElement == 'string') elemen
scottchen 2017/03/18 01:05:47 Done.
if (!element)
@@ -105,13 +105,18 @@ cr.define('cr.ui', function() {
*
* @param {string} type The type of element to track focus of.
- * @param {string} query The selector of the element from this row's root.
+ * @param {string|HTMLElement} selector The selector of the element from
Dan Beam 2017/03/18 00:09:57 selectorOrElement
scottchen 2017/03/18 01:05:47 Done.
return false;

Powered by Google App Engine
This is Rietveld 408576698